@@ -98,6 +98,11 @@ def decodeCustomTx(hex,DfMarker):
                     }
             return None
         return res
+    elif DfMarker == 'DfTS':
+        res = decodeDfTxTokenSplit(hex)
+        if res != None:
+            res['name'] = 'DfTS'
+        return res
     else:
         return {
             'txType': DfMarker,
@@ -364,6 +369,14 @@ def decodeDepositToVault(hex):
     ]
     return searchHex(variables,hex)
 
+# NOT a DfTx Function!
+def decodeDfTxTokenSplit(hex):
+    variables = [
+        {'bytesCount': 4, 'key': 'typeId', 'type': int,'endian':'little'},
+        {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+        {'bytesCount': 4,'key': 'multiplier', 'type': int,'endian':'little'}
+    ]
+    return searchHex(variables,hex)
     
 def recursiveSearchHex(variable,hex):
     abort = False
